AppStateWrapper

Struct AppStateWrapper 

pub struct AppStateWrapper<S: AppState>(/* private fields */);
Holds application state.

Cloning

It can be useful to clone AppStateWrapper’s in order to pass state into event handler closures.

All clones will point to the same inner state.

Cloning an AppStateWrapper is a very cheap operation.

Implementations

Source

impl<S: AppState> AppStateWrapper<S>

pub fn new(state: S) -> Self

Create a new AppStateWrapper.

pub fn msg(&mut self, msg: S::Message)

Acquire write access to the AppState then send a message.

pub fn read(&self) -> RwLockReadGuard<'_, S>

Acquire read access to AppState.