pub struct AppStateWrapper<S: AppState>(/* private fields */);Expand description
Holds application state.
Cloning
It can be useful to clone AppStateWrapper’s in order to pass state into event handler
closures.
All clones will point to the same inner state.
Cloning an AppStateWrapper is a very cheap operation.
Implementations